@@ -148,7 +148,7 @@ NULL
 #'  One can then use the generic function \code{\link{plot}} to produce a numbered plot of landmark 
 #'  positions and potentially add links, in order to review landmark positions
 #'
-#' @param A Either a list (length n, p x k), A 3D array (p x k x n), or a matrix (pk X n) containing GPA-aligned coordinates for a set of specimens
+#' @param A Either a list (length n, p x k), A 3D array (p x k x n), or a matrix (n x pk) containing GPA-aligned coordinates for a set of specimens
 #' @keywords utilities
 #' @export
 #' @author Julien Claude
@@ -159,9 +159,19 @@ NULL
 #'
 #' mshape(Y.gpa$coords)   #mean (consensus) configuration
 mshape<-function(A){
-  if(is.array(A)) res <- apply(A,c(1,2),mean)
+  if(is.array(A)) {
+    dims <- dim(A)
+    if(length(dims) == 3) res <- apply(A,c(1,2),mean) else
+      if(length(dims) == 2){
+        if(dims[[2]] == 2 || dims[[2]] == 3) res <- A else
+        {
+          cat("\nWarning: It appears that data are in a matrix with specimens as rows.")
+          cat("\nMeans are found for each column of the matrix.\n\n")
+          res <- colMeans(A)
+        }
+      }
+  }
   if(is.list(A)) res <- Reduce("+", A)/length(A)
-  if(is.matrix(A)) res <- colMeans(A)
   if(!is.array(A) && !is.list(A) && !is.matrix(A)) stop("There are not multiple configurations from which to obtain a mean.")
   class(res) <- c("mshape", "matrix")
   return(res)
@@ -260,7 +270,7 @@ rotate.mat <- function(M,Y){
 
 # tangents
 # finds tangents in a matrix based on sliders
-# used in all functions associated with pPga.wCurvs
+# used in all functions associated with pPga.wCurves
 tangents = function(s,x, scaled=FALSE){ # s = curves, x = landmarks
   ts <- x[s[,3],] - x[s[,1],]
   if(scaled==TRUE) {
@@ -275,10 +285,10 @@ tangents = function(s,x, scaled=FALSE){ # s = curves, x = landmarks
 # nearest
 # finds nearest points on surfaces for sliding semilandmakrs
 # used in all functions associated with pPga.wCurves
-nearest <- function(X,m,k=4) {
+nearest <- function(X, m, k = 4) {
   a <- X[m,]
   b <- sapply(1:nrow(X), function (j) sum((a-X[j,])^2))
-  match(sort(b)[2:(k+1)],b)
+  match(sort(b)[2:(k + 1)], b)
 }
 
 # getU
@@ -424,12 +434,15 @@ pGpa <- function(Y, PrinAxes = FALSE, Proj = FALSE, max.iter = 5){
 # used in semilandmarks functions, within the larger gpagen framework
 getSurfPCs <- function(y, surf){
   V <- La.svd(center(y), nu=0)$vt
-  p <- nrow(y); k <- ncol(y)
+  k <- ncol(y)
+  kk <- round(0.05 * length(surf))
+  kk <- max(c(k, kk))
+  p <- nrow(y)
   pc.match <- 1:p; pc.match[-surf] = NA
   nearpts <- lapply(1:p, function(j) {
     nn <- pc.match[j]
     if(is.na(nn)) 0 else
-      c(nearest(y,nn, k=k+1),nn)})
+      c(nearest(y, nn, k = kk+1), nn)})
   tmp.pts <- lapply(1:p, function(j) {
     k <- nearpts[[j]]
     if(sum(k) > 0) x <- center(y[k,]) else x <- NA
@@ -2320,7 +2333,7 @@ pic.prep <- function(phy, nx, px){
 
 ace.pics <- function(ntip, nnode, edge1, edge2, edge_len, phe, contr,
                  var_contr, tip.label, i.seq, x) {
-  phe[1:ntip,] <- if (is.null(names(x))) x else x[tip.label,]
+  phe[1:ntip,] <- if (is.null(rownames(x))) x else x[tip.label,]
   N <- ntip + nnode
   for(ii in 1:nnode) {
     anc <- edge1[i.seq[ii]]
@@ -2345,15 +2358,20 @@ ace.pics <- function(ntip, nnode, edge1, edge2, edge_len, phe, contr,
 # multivariate as opposed to fastAnc
 
 anc.BM <- function(phy, Y){
+  if(!is.matrix(Y)) Y <- as.matrix(Y)
+  Y <- as.matrix(Y[phy$tip.label,])
   phy <- reorder.phy(phy)
   n <- length(phy$tip.label)
   out <- t(sapply(1:phy$Nnode, function(j){
     phy.j <- multi2di.phylo(root.phylo(phy, node = j + n))
     preps <- pic.prep(phy.j, NROW(Y), NCOL(Y))
     preps$x <- Y
+    preps$tip.label <- phy$tip.label
     out <- do.call(ace.pics, preps)
     out[n + 1,]
   }))
+  
+  if(length(out) == (n-1)) out <- t(out)
   dimnames(out) <- list(1:phy$Nnode + length(phy$tip.label), colnames(Y))
   out
 }
